#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# === This file is part of Calamares - <http://github.com/calamares> ===
#
#   Copyright 2016, Matthias Klumpp <mak@debian.org>
#
#   Calamares is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   Calamares is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with Calamares. If not, see <http://www.gnu.org/licenses/>.

import libcalamares

import os
import subprocess

from libcalamares.utils import target_env_call, check_target_env_call


def target_apt_install(pkgs):
    """ Installs a list of packages using APT.

    :param pkgs:
    """

    cmd = ["sh", "-c", "DEBIAN_FRONTEND=noninteractive apt-get -q -y install {}".format(" ".join(pkgs))]
    check_target_env_call(cmd)


def install_bootloader_package(fw_type):
    """ Uses APT to install the right bootloader package from the live-boot image.

    :param fw_type:
    :return:
    """
    root_mount_point = libcalamares.globalstorage.value("rootMountPoint")

    # mount live medium
    live_medium_path = "/tmp/live-medium"
    live_medium_path_full = os.path.join(root_mount_point, "tmp", "live-medium")

    subprocess.call(["mkdir", "-p", live_medium_path_full])
    subprocess.call(["mount", "--bind", "/cdrom", live_medium_path_full])

    # write the repository snippet.
    # the suite "stable" is usually symlinked to the actual suite name, e.g. "dasyatis" in Tanglu.
    # this saves us from the pain of finding out the current default suite name or making it an additional setting.
    repo_snippet = os.path.join(root_mount_point, "etc", "apt", "sources.list.d", "tmp_live-medium.list")
    f = open(repo_snippet, 'w')
    f.write("deb [trusted=yes] file://{repo} {suite} main".format(repo=live_medium_path, suite='stable'))
    f.close()

    # update the APT cache
    check_target_env_call(["apt-get", "update"])

    if fw_type == "efi":
        efi_boot_loader = libcalamares.job.configuration.get("efiBootLoader")
        if efi_boot_loader == "systemd-boot":
            #target_apt_install(["systemd-boot"])
            # NOTE: systemd-boot doesn't exist in Debian yet
            pass
        else:
            target_apt_install(["grub-efi"])
    else:
        target_apt_install(["grub-pc"])

    # cleanup
    os.remove(repo_snippet)
    subprocess.call(["umount", live_medium_path_full])
    subprocess.call(["rmdir", live_medium_path_full])
    target_env_call(["apt-get", "update"])

def run():
    """ Starts procedure and passes 'fw_type' to other routine.

    :return:
    """
    if libcalamares.globalstorage.value("bootLoader") is None:
        return None

    fw_type = libcalamares.globalstorage.value("firmwareType")
    install_bootloader_package(fw_type)

    return None
